import React, { useState, useEffect, useCallback } from 'react';
import { Modal, Input, Button, message, Spin, Pagination, Table } from 'antd';
import { GetGroupUserTree, TestPush } from '@/services/messagemanage/messagemanage';
import styles from './PushTest.less';
import DragTable from '@/components/DragTable/DragTable';
import CardCheck from './CardCheck';

const PushTest = props => {
  const { confirmModal, onCancel, visible, pushTestMsg } = props;
  const [allList, setAllist] = useState([]); // 用于展示得数据
  const [checkList, setCheckList] = useState([]); // 选中得数据集合
  const [loading, setLoading] = useState(false);
  const [total, setTotal] = useState();
  const [currentPage, setCurrentPage] = useState(1);
  const [pageSize, setPageSize] = useState(10);
  const [searchName, setSearchName] = useState();

  useEffect(() => {
    if (visible) {
      setCurrentPage(1);
      getData(searchName, 1, pageSize);
    } else {
      setCheckList([]);
      setAllist([]);
      setSearchName('');
    }
  }, [visible]);
  // 选中后得回调函数
  const checkCallBack = useCallback(newCheckList => {
    if (newCheckList) {
      setCheckList(newCheckList);
    }
  });
  // 监听分页
  const paginationChange = (page, pageSizes) => {
    setCurrentPage(page);
    setPageSize(pageSizes);
    getData(searchName, page, pageSizes);
  };
  // 提交勾选的测试人员
  const onFinish = () => {
    console.log(pushTestMsg);
    console.log(pushTestMsg.item.AgentConfig);
    TestPush({
      theme: pushTestMsg.ThemeName,
      msgType: pushTestMsg.MsgType,
      tousers: checkList.map(item => item.value),
      pushPath: pushTestMsg.item.AgentConfig ? pushTestMsg.item.AgentConfig.Url : '',
      msgTypeId: pushTestMsg.ID.toString(),
    })
      .then(res => {
        if (res.code === 0) {
          confirmModal();
          message.success('测试推送成功');
        } else {
          message.error(res.msg);
        }
      })
      .catch(() => {
        message.error('网络异常，请稍后再试');
      });
  };
  // 搜索
  const onSearch = () => {
    setCurrentPage(1);
    getData(searchName, 1, pageSize);
  };
  // 重置
  const onReset = () => {
    setCurrentPage(1);
    getData('', 1, pageSize);
    setSearchName('');
  };
  // 搜索框监听
  const searchChange = e => {
    setSearchName(e.target.value);
  };
  // 获取数据
  const getData = (username, page, pageSizes) => {
    setLoading(true);
    GetGroupUserTree({
      key: username,
      pageSize: pageSizes,
      PageIndex: page,
    })
      .then(res => {
        setLoading(false);
        if (res.code === 0) {
          setTotal(res.data.count);
          // 数据处理成checkbox组件需要得形式
          let list = res.data.data.map(item => {
            let indeterminate = false;
            let checkedList = [];
            let checkAll = false;
            let options = item.users.map(val => {
              checkList.forEach(ele => {
                if (val.userId === ele.value) {
                  checkedList.push(ele.value);
                }
              });
              return {
                label: val.userName,
                value: val.userId,
              };
            });
            if (checkedList.length === options.length && checkedList.length > 0) {
              checkAll = true;
            }
            if (checkedList.length < options.length && checkedList.length > 0) {
              indeterminate = true;
            }
            return {
              groupName: item.groupName,
              groupId: item.groupId,
              indeterminate,
              checkAll,
              checkedList,
              plainOptions: options,
            };
          });
          setAllist(list);
        } else {
          message.error(res.msg);
        }
      })
      .catch(() => {
        setLoading(false);
        message.error('网络异常，请稍后再试');
      });
  };
  // 拖拽后的回调函数
  const dragCallBack = val => {
    if (val) {
      setCheckList(val);
    }
  };
  const columns = [
    {
      title: '已选推送人',
      dataIndex: 'label',
      key: 'label',
      width: 300,
    },
  ];
  return (
    <>
      <Modal
        title="选择推送人"
        visible={visible}
        onOk={onFinish}
        width="900px"
        onCancel={onCancel}
        maskClosable={false}
        destroyOnClose
        centered
      >
        <div className={styles.pushTestContent}>
          <div className={styles.leftContent}>
            {/* 头部搜索框 */}
            <div className={styles.searchHeader}>
              <Input.Search
                value={searchName}
                placeholder="请输入部门或用户"
                onChange={searchChange}
                onSearch={onSearch}
                enterButton
                style={{ width: '300px', marginRight: '15px' }}
              />
              <Button type="primary" htmlType="submit" onClick={onReset}>
                重置
              </Button>
            </div>
            {/* 复选框模块 */}
            <Spin spinning={loading}>
              <div className={styles.checkContainer}>
                {allList.map((item, index) => (
                  <div className={styles.checkBoxContent} key={item.groupId}>
                    <CardCheck
                      cardMsg={item}
                      cardIndex={index}
                      callback={(val, newCheckList) => checkCallBack(val, newCheckList)}
                      checkList={checkList}
                    />
                  </div>
                ))}
              </div>
            </Spin>
          </div>
          <div className={styles.tableRight}>
            <Table
              bordered
              style={{ width: '350px', overflowX: 'hidden' }}
              rowKey={record => record.value}
              columns={columns}
              dataSource={checkList}
              pagination={false}
              size="small"
              dragCallBack={dragCallBack}
              scroll={{ y: 530 }}
              ItemTypes="pushTest"
            />
          </div>
        </div>
        <div>
          {/* 分页 */}
          <Pagination
            total={total}
            showTotal={(totals, range) => `共 ${totals} 条`}
            defaultPageSize={pageSize}
            defaultCurrent={1}
            current={currentPage}
            onChange={paginationChange}
            style={{ width: '100%' }}
            size="small"
            showQuickJumper
            showSizeChanger
          />
        </div>
      </Modal>
    </>
  );
};

export default PushTest;
